==> maliang_extensions-0.1.0-py3-none-any.whl: maliang/extensions/__init__.py <==
"""Some extensions for `maliang`

* GitHub: https://github.com/TempAccountOfMuxue1230/maliang-extensions
* PyPI: https://pypi.org/project/maliang-extensions/

If you ❤️ this package, please leave your ⭐ to us, thank you very much!

![Stars](https://img.shields.io/github/stars/TempAccountOfMuxue1230/maliang-extensions) \
![Forks](https://img.shields.io/github/forks/TempAccountOfMuxue1230/maliang-extensions) \
![Watchers](https://img.shields.io/github/watchers/TempAccountOfMuxue1230/maliang-extensions)
"""

# MIT License

# Copyright (c) 2025 MuXue1230

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

__version__ = "0.1.0"
__author__ = "MuXue1230"
__license__ = "MIT"

from .widgets import *
from .core import *

==> maliang_extensions-0.1.1a2-py3-none-any.whl: maliang/extensions/__init__.py <==
"""Some extensions for `maliang`

* GitHub: https://github.com/TempAccountOfMuxue1230/maliang-extensions
* PyPI: https://pypi.org/project/maliang-extensions/

If you ❤️ this package, please leave your ⭐ to us, thank you very much!

![Stars](https://img.shields.io/github/stars/TempAccountOfMuxue1230/maliang-extensions) \
![Forks](https://img.shields.io/github/forks/TempAccountOfMuxue1230/maliang-extensions) \
![Watchers](https://img.shields.io/github/watchers/TempAccountOfMuxue1230/maliang-extensions)
"""

# MIT License

# Copyright (c) 2025 MuXue1230

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

__version__ = "0.1.1a2"
__author__ = "MuXue1230"
__license__ = "MIT"

from .widgets import *
from .core import *
